@@ -14,7 +14,7 @@ use crate::package::{PackageExtractArgs, PackageProcess};
 use crate::util;
 
 #[derive(Debug, Clone, Copy, ValueEnum)]
-#[clap(rename_all = "verbatim")]
+#[value(rename_all = "verbatim")]
 pub enum ResolveType {
     SourceForDebianUnstable,
     BinaryAllForDebianTesting,
@@ -31,13 +31,13 @@ pub struct BuildOrderArgs {
     /// specific, e.g. <crate>-1.2.3, then <crate>-1.2, then <crate>-1 and
     /// finally <crate>. The config file is read from the debian/debcargo.toml
     /// subpath of the looked-up subdirectory.
-    #[clap(long)]
+    #[arg(long)]
     config_dir: Option<PathBuf>,
     /// Resolution type
-    #[clap(value_enum, long, default_value = "SourceForDebianUnstable")]
+    #[arg(value_enum, long, default_value = "SourceForDebianUnstable")]
     resolve_type: ResolveType,
     /// Emulate resolution as if every package were built with --collapse-features.
-    #[clap(long)]
+    #[arg(long)]
     emulate_collapse_features: bool,
 }
 
@@ -61,18 +61,17 @@ fn get_build_deps(
     let (_, crate_dep_info, config) = crate_details;
     let all_deps = crate_dep_info
         .iter()
-        .map(|(_, v)| v.1.iter())
-        .flatten()
+        .flat_map(|(_, v)| v.1.iter())
         .cloned()
         .collect::<HashSet<_>>();
     let feature_deps: HashSet<Dependency> =
-        HashSet::from_iter(transitive_deps(crate_dep_info, package.1).1);
+        HashSet::from_iter(transitive_deps(crate_dep_info, package.1)?.1);
     let additional_deps = if emulate_collapse_features || config.collapse_features {
         all_deps.clone()
     } else {
         // TODO: if build_depends_features is an override, use that instead of "default"
         // TODO: also deprecate build_depends_excludes
-        HashSet::from_iter(transitive_deps(crate_dep_info, "default").1)
+        HashSet::from_iter(transitive_deps(crate_dep_info, "default")?.1)
     };
     let hard_deps = feature_deps
         .union(&additional_deps)
@@ -188,6 +187,7 @@ pub fn build_order(args: BuildOrderArgs) -> Result<Vec<PackageId>> {
     let seed_id = resolve_info(&mut infos, &mut cache, config_dir, &seed_dep, true)?;
 
     let mut next = |idf: &PackageIdFeat| -> Result<(Vec<PackageIdFeat>, Vec<PackageIdFeat>)> {
+        log::trace!("{} getting build deps..", idf);
         let (hard, soft) = get_build_deps(
             infos
                 .get(&idf.0)
