@@ -217,8 +217,7 @@ pub fn package_field_for_feature<'a>(
     Some(feature)
         .into_iter()
         .chain(f_provides.iter().map(|s| PackageKey::feature(s)))
-        .map(move |f| get_field(f).into_iter().flatten())
-        .flatten()
+        .flat_map(move |f| get_field(f).into_iter().flatten())
         .map(|s| s.to_string())
         .collect()
 }
