@@ -1,5 +1,5 @@
 use cargo::core::manifest;
-use chrono::{DateTime, Datelike, NaiveDateTime, Utc};
+use chrono::{Datelike, NaiveDateTime, TimeZone, Utc};
 use git2::Repository;
 use regex;
 use tempfile;
@@ -318,19 +318,19 @@ fn copyright_fromgit(repo_url: &str) -> Result<String> {
     let first_commit = repo.find_commit(first_id)?;
     let latest_commit = repo.find_commit(latest_id)?;
 
-    let first_year = DateTime::<Utc>::from_utc(
-        NaiveDateTime::from_timestamp_opt(first_commit.time().seconds(), 0)
-            .ok_or(anyhow::Error::msg("lo"))?,
-        Utc,
-    )
-    .year();
+    let first_year = Utc
+        .from_utc_datetime(
+            &NaiveDateTime::from_timestamp_opt(first_commit.time().seconds(), 0)
+                .ok_or(anyhow::Error::msg("lo"))?,
+        )
+        .year();
 
-    let latest_year = DateTime::<Utc>::from_utc(
-        NaiveDateTime::from_timestamp_opt(latest_commit.time().seconds(), 0)
-            .ok_or(anyhow::Error::msg("lo"))?,
-        Utc,
-    )
-    .year();
+    let latest_year = Utc
+        .from_utc_datetime(
+            &NaiveDateTime::from_timestamp_opt(latest_commit.time().seconds(), 0)
+                .ok_or(anyhow::Error::msg("lo"))?,
+        )
+        .year();
 
     let notice = match first_year.cmp(&latest_year) {
         Ordering::Equal => format!("{}", first_year),
@@ -373,9 +373,13 @@ pub fn debian_copyright(
     if let Some(ref license_file_name) = meta.license_file {
         let license_file = manifest_path.with_file_name(license_file_name);
         let mut text = Vec::new();
-        fs::File::open(license_file)?.read_to_end(&mut text)?;
         licenses.reserve(1);
-        let stext = String::from_utf8(text)?;
+        let stext = match fs::File::open(license_file).and_then(|mut f| f.read_to_end(&mut text)) {
+            Ok(_) => String::from_utf8(text)?,
+            Err(e) => {
+                format!("Failed to read license from {license_file_name} - {e:?}")
+            }
+        };
         licenses.push(License::new(
             "UNKNOWN-LICENSE; FIXME (overlay)".to_string(),
             stext,
@@ -384,7 +388,7 @@ pub fn debian_copyright(
         licenses = get_licenses(license).unwrap();
         crate_license = license
             .trim()
-            .replace("/", " or ")
+            .replace('/', " or ")
             .replace(" OR ", " or ")
             .replace(" AND ", " and ");
     } else {
