@@ -186,7 +186,7 @@ pub fn prepare_orig_tarball(
         fs::copy(crate_file.path(), &temp_archive_path)?;
     }
 
-    fs::rename(temp_archive_path, &tarball)?;
+    fs::rename(temp_archive_path, tarball)?;
     Ok(())
 }
 
@@ -220,7 +220,7 @@ it's a maintenance burden. Use debcargo.toml instead."
     }
     if tempdir.path().join("patches").join("series").exists() {
         // apply patches to Cargo.toml in case they exist, and re-read it
-        let output_dir = &fs::canonicalize(&output_dir)?;
+        let output_dir = &fs::canonicalize(output_dir)?;
         let stderr = || {
             // create a new owned handle to stderr
             fs::OpenOptions::new()
@@ -231,18 +231,18 @@ it's a maintenance burden. Use debcargo.toml instead."
         expect_success(
             Command::new("quilt")
                 .stdout(stderr())
-                .current_dir(&output_dir)
+                .current_dir(output_dir)
                 .env("QUILT_PATCHES", tempdir.path().join("patches"))
-                .args(&["push", "--quiltrc=-", "-a"]),
+                .args(["push", "--quiltrc=-", "-a"]),
             "failed to apply patches using quilt",
         );
         crate_info.replace_manifest(&output_dir.join("Cargo.toml"))?;
         expect_success(
             Command::new("quilt")
                 .stdout(stderr())
-                .current_dir(&output_dir)
+                .current_dir(output_dir)
                 .env("QUILT_PATCHES", tempdir.path().join("patches"))
-                .args(&["pop", "--quiltrc=-", "-a"]),
+                .args(["pop", "--quiltrc=-", "-a"]),
             "failed to unapply patches",
         );
     }
@@ -550,7 +550,7 @@ echo "debcargo testing: suppressing dh-cargo-built-using";;
             write!(changelog, "{}\n{}", changelog_new_entry, changelog_old)?;
         }
         // the new file might be shorter, truncate it to the current cursor position
-        let pos = changelog.seek(io::SeekFrom::Current(0))?;
+        let pos = changelog.stream_position()?;
         changelog.set_len(pos)?;
     }
 
@@ -619,9 +619,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
         "features_with_deps: {:?}",
         features_with_deps
             .iter()
-            .map(|(&f, &(ref ff, ref dd))| {
-                (f, (ff, dd.iter().map(show_dep).collect::<Vec<_>>()))
-            })
+            .map(|(&f, (ff, dd))| { (f, (ff, dd.iter().map(show_dep).collect::<Vec<_>>())) })
             .collect::<Vec<_>>()
     );
     let meta = crate_info.metadata();
@@ -647,7 +645,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
             .iter()
             .map(|x| x.to_string());
         // note: please keep this in sync with build_order::dep_features
-        let (default_features, default_deps) = transitive_deps(&features_with_deps, "default");
+        let (default_features, default_deps) = transitive_deps(&features_with_deps, "default")?;
         //debcargo_info!("default_features: {:?}", default_features);
         //debcargo_info!("default_deps: {:?}", deb_deps(config, &default_deps)?);
         let extra_override_deps = package_field_for_feature(
@@ -655,9 +653,9 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
             PackageKey::feature("default"),
             &default_features,
         );
-        let build_deps_extra = ["cargo:native", "rustc:native", "libstd-rust-dev"]
-            .iter()
-            .map(|s| s.to_string())
+        let rustc = rustc_dep(&crate_info.rust_version());
+        let build_deps_extra = ["cargo:native".into(), rustc, "libstd-rust-dev".into()]
+            .into_iter()
             .chain(deb_deps(config, &default_deps)?)
             .chain(extra_override_deps);
         if !bins.is_empty() {
@@ -699,7 +697,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
     let (crate_summary, crate_description) = crate_info.get_summary_description();
     let summary_prefix = crate_summary.unwrap_or(format!("Rust crate \"{}\"", crate_name));
     let description_prefix = {
-        let tmp = crate_description.unwrap_or_else(|| "".to_string());
+        let tmp = crate_description.unwrap_or_default();
         if tmp.is_empty() {
             tmp
         } else {
@@ -709,20 +707,21 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
 
     if lib {
         // debian/tests/control
-        let all_features_test_broken = Some(&"@")
-            .into_iter()
-            .chain(features_with_deps.keys())
-            .any(|f| test_is_marked_broken(f).unwrap_or(false));
+        let all_features_test_broken = match test_is_marked_broken("@") {
+            Some(v) => v,
+            None => features_with_deps
+                .keys()
+                .any(|f| test_is_marked_broken(f).unwrap_or(false)),
+        };
         let all_features_test_depends = Some(&"@")
             .into_iter()
             .chain(features_with_deps.keys())
-            .map(|f| {
+            .flat_map(|f| {
                 config
                     .package_test_depends(PackageKey::feature(f))
                     .into_iter()
                     .flatten()
             })
-            .flatten()
             .map(|s| s.to_string())
             .chain(dev_depends.clone())
             .collect::<Vec<_>>();
@@ -808,9 +807,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
             "working_features_with_deps: {:?}",
             working_features_with_deps
                 .iter()
-                .map(|(&f, &(ref ff, ref dd))| {
-                    (f, (ff, dd.iter().map(show_dep).collect::<Vec<_>>()))
-                })
+                .map(|(&f, (ff, dd))| { (f, (ff, dd.iter().map(show_dep).collect::<Vec<_>>())) })
                 .collect::<Vec<_>>()
         );
         let (mut provides, reduced_features_with_deps) = if config.collapse_features {
@@ -878,9 +875,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
             "reduced_features_with_deps: {:?}",
             reduced_features_with_deps
                 .iter()
-                .map(|(&f, &(ref ff, ref dd))| {
-                    (f, (ff, dd.iter().map(show_dep).collect::<Vec<_>>()))
-                })
+                .map(|(&f, (ff, dd))| { (f, (ff, dd.iter().map(show_dep).collect::<Vec<_>>())) })
                 .collect::<Vec<_>>()
         );
         // end transforming dependencies
@@ -913,12 +908,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
                 }
             };
             let description_suffix = if feature.is_empty() {
-                format!(
-                    "This package contains the source for the \
-                     Rust {} crate, packaged by debcargo for use \
-                     with cargo and dh-cargo.",
-                    crate_name
-                )
+                format!("Source code for Debianized Rust crate \"{}\"", crate_name)
             } else {
                 format!(
                     "This metapackage enables feature \"{}\" for the \
@@ -976,8 +966,8 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
             // If any overrides present for this package it will be taken care.
             package.apply_overrides(config, pk, f_provides);
 
-            match package.summary_check_len() {
-                Err(()) => writeln!(
+            if package.summary_check_len().is_err() {
+                writeln!(
                     control,
                     concat!(
                         "\n",
@@ -985,9 +975,8 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
                         "auto-generated summary for {} is very long, consider overriding"
                     ),
                     package.name(),
-                )?,
-                Ok(()) => {}
-            };
+                )?;
+            }
 
             write!(control, "\n{}", package)?;
 
@@ -1004,7 +993,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
 
             // Generate tests for all features in this package
             for f in crate_features {
-                let (feature_deps, _) = transitive_deps(&features_with_deps, f);
+                let (feature_deps, _) = transitive_deps(&features_with_deps, f)?;
 
                 // args
                 let mut args = if f == "default" || feature_deps.contains(&"default") {
@@ -1023,13 +1012,12 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<std::fs::File, s
                 let test_depends = Some(f)
                     .into_iter()
                     .chain(feature_deps)
-                    .map(|f| {
+                    .flat_map(|f| {
                         config
                             .package_test_depends(PackageKey::feature(f))
                             .into_iter()
                             .flatten()
                     })
-                    .flatten()
                     .map(|s| s.to_string())
                     .chain(dev_depends.clone())
                     .collect::<Vec<_>>();
@@ -1184,6 +1172,29 @@ fn reduce_provides(
     (provides, features_with_deps)
 }
 
+fn rustc_dep(min_ver: &Option<&str>) -> String {
+    if let Some(min_ver) = min_ver {
+        format!("rustc:native (>= {})", min_ver)
+    } else {
+        "rustc:native".into()
+    }
+}
+
+#[cfg(test)]
+mod test {
+    use super::rustc_dep;
+
+    #[test]
+    fn rustc_dep_includes_minver() {
+        assert_eq!("rustc:native (>= 1.65)", rustc_dep(&Some(&"1.65")));
+    }
+
+    #[test]
+    fn rustc_dep_excludes_minver() {
+        assert_eq!("rustc:native", rustc_dep(&None));
+    }
+}
+
 fn changelog_or_new(tempdir: &Path) -> Result<(fs::File, String)> {
     let mut changelog = fs::OpenOptions::new()
         .read(true)
@@ -1203,14 +1214,14 @@ fn changelog_first_last(tempdir: &Path) -> Result<(i32, i32)> {
     let mut first = None;
     for x in ChangelogIterator::from(&changelog_data) {
         let e = ChangelogEntry::from_str(x)?;
-        if None == last {
+        if last.is_none() {
             last = Some(e.date.year());
         }
         first = Some(e.date.year());
     }
-    if None == last {
-        Err(format_err!("changelog had no entries"))
+    if let Some(last) = last {
+        Ok((first.unwrap(), last))
     } else {
-        Ok((first.unwrap(), last.unwrap()))
+        Err(format_err!("changelog had no entries"))
     }
 }
