@@ -3,4 +3,7 @@ pub mod errors;
 pub mod config;
 pub mod crates;
 pub mod debian;
-pub mod util;
+mod util;
+
+pub mod build_order;
+pub mod package;
